package HTML::Puzzle;


$VERSION = "0.07";
sub Version { $VERSION; }

require 5.005;
use HTML::Puzzle::DBTable;
use HTML::Puzzle::Format;


1;
__END__
